==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/mail_templates_controller.rb <==
# -*- coding: utf-8 -*-
class MailTemplatesController < ApplicationController
  class_desc :display_name => 'メールテンプレート管理'

  # 新規登録画面表示（PCメール作成画面）
  def new
    # バリデーションエラーからの戻り
    if flash[:mail_template]
      @mail_template = flash[:mail_template]
    # 戻るボタンからの戻り
    elsif params[:use_session]
      @mail_template = session[:mail_template_mail_template]
    # 初期表示
    else
      session[:mail_template_mail_template] = nil
      @mail_template = MailTemplate.new(:content_type_div => MailTemplate.content_type_div_id_by_key(:text), :mail_type_div => MailTemplate.mail_type_div_id_by_key(:thanks))
    end
  end

  desc :category_name => :create
  # 新規登録画面表示（携帯メール作成画面）
  # PCメール作成画面で入力された内容をチェックして、携帯メール作成画面を表示する
  def new_pc_template
    # バリデーションエラーからの戻り
    if flash[:mail_template]
      @mail_template = flash[:mail_template]
      render(:action => :new_mobile)
      return
    # 登録情報が存在しない（不正な遷移）
    elsif params[:mail_template].blank?
      raise ActionController::UnknownAction, "登録情報が存在しません。"
    end

    # PCメールのバリデーションチェック
    @mail_template = MailTemplate.new(params[:mail_template])
    @mail_template.validate_for_pc_only = true
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :new)
      return
    end
    # 携帯メール入力画面表示
    @mail_template.validate_for_pc_only = false
    session[:mail_template_mail_template] = @mail_template
    render(:action => :new_mobile)
  end

  desc :auth_as => :create
  # 登録確認
  def confirm_create
    @mail_template = session[:mail_template_mail_template]
    @mail_template.attributes = params[:mail_template]
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :new_pc_template)
      return
    end
  end

  # 登録
  def create
    @mail_template = session[:mail_template_mail_template]
    using_template_count = MailTemplate.count(
      :conditions => ['mail_type_div = ? AND use_div = ? AND locale = ?',
        @mail_template.mail_type_div, MailTemplate.use_div_id_by_key(:true),
        @mail_template.locale])
    @mail_template.use_div = (using_template_count > 0) ? MailTemplate.use_div_id_by_key(:false) : MailTemplate.use_div_id_by_key(:true)
    if @mail_template.save
      redirect_to(:action => :search)
    else
      flash[:mail_template] = @mail_template
      redirect_to(:action => :new)
    end
    session[:mail_template_mail_template] = nil
  end

  # 編集画面表示
  def edit
    # バリデーションエラーからの戻り
    if flash[:mail_template]
      @mail_template = flash[:mail_template]
      return
    end
    # 戻るボタンからの戻り
    if params[:mail_template]
      @mail_template = MailTemplate.find params[:id]
      @mail_template.attributes = params[:mail_template]
    # 初期表示
    else
      @mail_template = MailTemplate.find params[:id]
    end
  end

  desc :auth_as => :update
  # 更新確認
  def confirm_update
    @mail_template = MailTemplate.find(params[:id])
    @mail_template.attributes= params[:mail_template]
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :edit, :id => params[:id])
    end
  end

  # 更新
  def update
    @mail_template = MailTemplate.find(params[:id])
    @mail_template.attributes= params[:mail_template]
    @mail_template.use_div_key = :true if params[:use_div] == 'checked'
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :edit, :id => params[:id])
      return
    end
    @mail_template.save_and_change_use_div

    redirect_to :action => :search
  end

  desc :category_name => :destroy, :display_name => 'メールテンプレート削除'
  # 削除
  def delete
    @mail_template = MailTemplate.find params[:id]
    @mail_template.destroy
    redirect_to(:action => :search)
  end

  desc :auth_as => :search
  # 詳細
  def show
    @mail_template = MailTemplate.find params[:id]
  end

  desc :category_name => :index, :display_name => 'メールテンプレート検索'
  # 一覧
  def search
    @condition = session[:mail_template_search_cond] if session[:mail_template_search_cond]
    if params[:condition]
      @condition = MailTemplate::SearchCondition.new(params[:condition])
      session[:mail_template_search_cond] = @condition
    end

    per_page = @condition.disp_count.to_i if @condition
    per_page = (per_page.to_i == 0) ? 20 : per_page
    @mail_templates = MailTemplate.paginate(:page => params[:page], :per_page => per_page,
      :conditions => MailTemplate.create_condition(@condition))
    @mail_template_all = MailTemplate.all
  end

  desc :category_name => :update, :display_name => 'メールタイプ変更'
  def change_mail_type
    @mail_template = MailTemplate.new(:mail_type_div => params[:value])
    render :partial => 'form'
  end

end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/mail_templates_controller.rb <==
# -*- coding: utf-8 -*-
class MailTemplatesController < ApplicationController
  class_desc :display_name => 'メールテンプレート管理'

  # 新規登録画面表示（PCメール作成画面）
  def new
    # バリデーションエラーからの戻り
    if flash[:mail_template]
      @mail_template = flash[:mail_template]
    # 戻るボタンからの戻り
    elsif params[:use_session]
      @mail_template = session[:mail_template_mail_template]
    # 初期表示
    else
      session[:mail_template_mail_template] = nil
      @mail_template = MailTemplate.new(:content_type_div => MailTemplate.content_type_div_id_by_key(:text), :mail_type_div => MailTemplate.mail_type_div_id_by_key(:thanks))
    end
  end

  desc :auth_as => :create
  # 新規登録画面表示（携帯メール作成画面）
  # PCメール作成画面で入力された内容をチェックして、携帯メール作成画面を表示する
  def new_pc_template
    # バリデーションエラーからの戻り
    if flash[:mail_template]
      @mail_template = flash[:mail_template]
      render(:action => :new_mobile)
      return
    # 登録情報が存在しない（不正な遷移）
    elsif params[:mail_template].blank?
      raise ActionController::UnknownAction, "登録情報が存在しません。"
    end

    # PCメールのバリデーションチェック
    @mail_template = MailTemplate.new(params[:mail_template])
    @mail_template.validate_for_pc_only = true
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :new)
      return
    end
    # 携帯メール入力画面表示
    @mail_template.validate_for_pc_only = false
    session[:mail_template_mail_template] = @mail_template
    render(:action => :new_mobile)
  end

  desc :auth_as => :create
  # 登録確認
  def confirm_create
    @mail_template = session[:mail_template_mail_template]
    @mail_template.attributes = params[:mail_template]
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :new_pc_template)
      return
    end
  end

  # 登録
  def create
    @mail_template = session[:mail_template_mail_template]
    using_template_count = MailTemplate.count(
      :conditions => ['mail_type_div = ? AND use_div = ? AND locale = ?',
        @mail_template.mail_type_div, MailTemplate.use_div_id_by_key(:true),
        @mail_template.locale])
    @mail_template.use_div = (using_template_count > 0) ? MailTemplate.use_div_id_by_key(:false) : MailTemplate.use_div_id_by_key(:true)
    if @mail_template.save
      redirect_to(:action => :search)
    else
      flash[:mail_template] = @mail_template
      redirect_to(:action => :new)
    end
    session[:mail_template_mail_template] = nil
  end

  # 編集画面表示
  def edit
    # バリデーションエラーからの戻り
    if flash[:mail_template]
      @mail_template = flash[:mail_template]
      return
    end
    # 戻るボタンからの戻り
    if params[:mail_template]
      @mail_template = MailTemplate.find params[:id]
      @mail_template.attributes = params[:mail_template]
    # 初期表示
    else
      @mail_template = MailTemplate.find params[:id]
    end
  end

  desc :auth_as => :update
  # 更新確認
  def confirm_update
    @mail_template = MailTemplate.find(params[:id])
    @mail_template.attributes= params[:mail_template]
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :edit, :id => params[:id])
    end
  end

  # 更新
  def update
    @mail_template = MailTemplate.find(params[:id])
    @mail_template.attributes= params[:mail_template]
    @mail_template.use_div_key = :true if params[:use_div] == 'checked'
    unless @mail_template.valid?
      flash[:mail_template] = @mail_template
      redirect_to(:action => :edit, :id => params[:id])
      return
    end
    @mail_template.save_and_change_use_div

    redirect_to :action => :search
  end

  desc :category_name => :destroy, :display_name => 'メールテンプレート削除'
  # 削除
  def delete
    @mail_template = MailTemplate.find params[:id]
    @mail_template.destroy
    redirect_to(:action => :search)
  end

  desc :auth_as => :search
  # 詳細
  def show
    @mail_template = MailTemplate.find params[:id]
  end

  desc :category_name => :index, :display_name => 'メールテンプレート検索'
  # 一覧
  def search
    @condition = session[:mail_template_search_cond] if session[:mail_template_search_cond]
    if params[:condition]
      @condition = MailTemplate::SearchCondition.new(params[:condition])
      session[:mail_template_search_cond] = @condition
    end

    per_page = @condition.disp_count.to_i if @condition
    per_page = (per_page.to_i == 0) ? 20 : per_page
    @mail_templates = MailTemplate.paginate(:page => params[:page], :per_page => per_page,
      :conditions => MailTemplate.create_condition(@condition))
    @mail_template_all = MailTemplate.all
  end

  desc :auth_as => :update, :display_name => 'メールタイプ変更'
  def change_mail_type
    @mail_template = MailTemplate.new(:mail_type_div => params[:value])
    render :partial => 'form'
  end

end
